Module write

Module write 

Cryptostream types which operate over Write streams, providing both encryption and decryption facilities.

Use [write::Encryptor] to pass in plaintext and have it write the encrypted equivalent to the underlying Write stream, or use [write::Decryptor] to do the opposite and have decrypted plaintext written to the wrapped Write output each time encrypted bytes are written to the instance.

Structs

Decryptor
A decrypting stream adapter that decrypts what is written to it
Encryptor
An encrypting stream adapter that encrypts what is written to it.