Encryptor

Struct Encryptor 

pub struct Encryptor<W: Write> { /* private fields */ }
An encrypting stream adapter that encrypts what is written to it.

write::Encryptor is a stream adapter that sits atop a Write stream. Plaintext written to the Encryptor is encrypted and written to the underlying stream.

Implementations

Source

impl<W: Write> Encryptor<W>

pub fn new( writer: W, cipher: Cipher, key: &[u8], iv: &[u8], ) -> Result<Self, ErrorStack>

pub fn finish(self) -> Result<W, Error>

Finishes writing to the underlying cryptostream, padding the final block as needed, flushing all output. Returns the wrapped Write instance.