pub struct Encryptor<W: Write> { /* private fields */ }Expand description
An encrypting stream adapter that encrypts what is written to it.
write::Encryptor is a stream adapter that sits atop a Write stream. Plaintext written to
the Encryptor is encrypted and written to the underlying stream.
Implementations